@@ -7,6 +7,9 @@ from .utils import (
     is_token_valid,
     validate_url,
     login_to_server,
+    take_web_action_event,
+    abort_web_action_event,
+    SortOrder,
 )
 from .server_api import (
     RequestTypes,
@@ -27,6 +30,7 @@ from ._api import (
     change_token,
     set_environments,
     get_server_api_connection,
+    get_default_settings_variant,
     get_base_url,
     get_rest_url,
     get_ssl_verify,
@@ -42,10 +46,11 @@ from ._api import (
     set_site_id,
     get_client_version,
     set_client_version,
-    get_default_settings_variant,
     set_default_settings_variant,
     get_sender,
     set_sender,
+    get_sender_type,
+    set_sender_type,
     get_info,
     get_server_version,
     get_server_version_tuple,
@@ -66,7 +71,13 @@ from ._api import (
     get_events,
     update_event,
     dispatch_event,
+    delete_event,
     enroll_event_job,
+    get_activities,
+    get_activity_by_id,
+    create_activity,
+    update_activity,
+    delete_activity,
     download_file_to_stream,
     download_file,
     upload_file_from_stream,
@@ -85,6 +96,7 @@ from ._api import (
     get_attributes_fields_for_type,
     get_default_fields_for_type,
     get_addons_info,
+    get_addon_endpoint,
     get_addon_url,
     download_addon_private_file,
     get_installers,
@@ -99,10 +111,13 @@ from ._api import (
     delete_dependency_package,
     download_dependency_package,
     upload_dependency_package,
+    delete_addon,
+    delete_addon_version,
     upload_addon_zip,
     get_bundles,
     create_bundle,
     update_bundle,
+    check_bundle_compatibility,
     delete_bundle,
     get_project_anatomy_presets,
     get_default_anatomy_preset_name,
@@ -225,6 +240,7 @@ from ._api import (
     get_representations_links,
     get_representation_links,
     send_batch_operations,
+    send_activities_batch_operations,
 )
 
 
@@ -238,6 +254,9 @@ __all__ = (
     "is_token_valid",
     "validate_url",
     "login_to_server",
+    "take_web_action_event",
+    "abort_web_action_event",
+    "SortOrder",
 
     "RequestTypes",
     "ServerAPI",
@@ -255,6 +274,7 @@ __all__ = (
     "change_token",
     "set_environments",
     "get_server_api_connection",
+    "get_default_settings_variant",
     "get_base_url",
     "get_rest_url",
     "get_ssl_verify",
@@ -270,10 +290,11 @@ __all__ = (
     "set_site_id",
     "get_client_version",
     "set_client_version",
-    "get_default_settings_variant",
     "set_default_settings_variant",
     "get_sender",
     "set_sender",
+    "get_sender_type",
+    "set_sender_type",
     "get_info",
     "get_server_version",
     "get_server_version_tuple",
@@ -294,7 +315,13 @@ __all__ = (
     "get_events",
     "update_event",
     "dispatch_event",
+    "delete_event",
     "enroll_event_job",
+    "get_activities",
+    "get_activity_by_id",
+    "create_activity",
+    "update_activity",
+    "delete_activity",
     "download_file_to_stream",
     "download_file",
     "upload_file_from_stream",
@@ -313,6 +340,7 @@ __all__ = (
     "get_attributes_fields_for_type",
     "get_default_fields_for_type",
     "get_addons_info",
+    "get_addon_endpoint",
     "get_addon_url",
     "download_addon_private_file",
     "get_installers",
@@ -327,10 +355,13 @@ __all__ = (
     "delete_dependency_package",
     "download_dependency_package",
     "upload_dependency_package",
+    "delete_addon",
+    "delete_addon_version",
     "upload_addon_zip",
     "get_bundles",
     "create_bundle",
     "update_bundle",
+    "check_bundle_compatibility",
     "delete_bundle",
     "get_project_anatomy_presets",
     "get_default_anatomy_preset_name",
@@ -453,4 +484,5 @@ __all__ = (
     "get_representations_links",
     "get_representation_links",
     "send_batch_operations",
+    "send_activities_batch_operations",
 )
