@@ -389,7 +389,9 @@ def representations_graphql_query(fields):
     repre_ids_var = query.add_variable("representationIds", "[String!]")
     repre_names_var = query.add_variable("representationNames", "[String!]")
     version_ids_var = query.add_variable("versionIds", "[String!]")
-    has_links_var = query.add_variable("representationHasLinks", "HasLinksFilter")
+    has_links_var = query.add_variable(
+        "representationHasLinks", "HasLinksFilter"
+    )
     statuses_var = query.add_variable(
         "representationStatuses", "[String!]"
     )
@@ -568,23 +570,26 @@ def workfiles_info_graphql_query(fields):
     return query
 
 
-def events_graphql_query(fields):
-    query = GraphQlQuery("Events")
+def events_graphql_query(fields, order, use_states=False):
+    query = GraphQlQuery("Events", order=order)
     topics_var = query.add_variable("eventTopics", "[String!]")
     ids_var = query.add_variable("eventIds", "[String!]")
     projects_var = query.add_variable("projectNames", "[String!]")
-    states_var = query.add_variable("eventStates", "[String!]")
+    statuses_var = query.add_variable("eventStatuses", "[String!]")
     users_var = query.add_variable("eventUsers", "[String!]")
     include_logs_var = query.add_variable("includeLogsFilter", "Boolean!")
     has_children_var = query.add_variable("hasChildrenFilter", "Boolean!")
     newer_than_var = query.add_variable("newerThanFilter", "String!")
     older_than_var = query.add_variable("olderThanFilter", "String!")
 
+    statuses_filter_name = "statuses"
+    if use_states:
+        statuses_filter_name = "states"
     events_field = query.add_field_with_edges("events")
     events_field.set_filter("ids", ids_var)
     events_field.set_filter("topics", topics_var)
     events_field.set_filter("projects", projects_var)
-    events_field.set_filter("states", states_var)
+    events_field.set_filter(statuses_filter_name, statuses_var)
     events_field.set_filter("users", users_var)
     events_field.set_filter("includeLogs", include_logs_var)
     events_field.set_filter("hasChildren", has_children_var)
@@ -634,3 +639,47 @@ def users_graphql_query(fields):
         for k, v in value.items():
             query_queue.append((k, v, field))
     return query
+
+
+def activities_graphql_query(fields, order):
+    query = GraphQlQuery("Activities", order=order)
+    project_name_var = query.add_variable("projectName", "String!")
+    activity_ids_var = query.add_variable("activityIds", "[String!]")
+    activity_types_var = query.add_variable("activityTypes", "[String!]")
+    entity_ids_var = query.add_variable("entityIds", "[String!]")
+    entity_names_var = query.add_variable("entityNames", "[String!]")
+    entity_type_var = query.add_variable("entityType", "String!")
+    changed_after_var = query.add_variable("changedAfter", "String!")
+    changed_before_var = query.add_variable("changedBefore", "String!")
+    reference_types_var = query.add_variable("referenceTypes", "[String!]")
+
+    project_field = query.add_field("project")
+    project_field.set_filter("name", project_name_var)
+
+    activities_field = project_field.add_field_with_edges("activities")
+    activities_field.set_filter("activityIds", activity_ids_var)
+    activities_field.set_filter("activityTypes", activity_types_var)
+    activities_field.set_filter("entityIds", entity_ids_var)
+    activities_field.set_filter("entityNames", entity_names_var)
+    activities_field.set_filter("entityType", entity_type_var)
+    activities_field.set_filter("changedAfter", changed_after_var)
+    activities_field.set_filter("changedBefore", changed_before_var)
+    activities_field.set_filter("referenceTypes", reference_types_var)
+
+    nested_fields = fields_to_dict(set(fields))
+
+    query_queue = collections.deque()
+    for key, value in nested_fields.items():
+        query_queue.append((key, value, activities_field))
+
+    while query_queue:
+        item = query_queue.popleft()
+        key, value, parent = item
+        field = parent.add_field(key)
+        if value is FIELD_VALUE:
+            continue
+
+        for k, v in value.items():
+            query_queue.append((k, v, field))
+
+    return query
