@@ -6,7 +6,8 @@ import string
 import platform
 import collections
 from urllib.parse import urlparse, urlencode
-from typing import Optional
+from typing import Optional, Dict, Any
+from enum import IntEnum
 
 import requests
 import unidecode
@@ -41,6 +42,20 @@ RepresentationHierarchy = collections.namedtuple(
 )
 
 
+class SortOrder(IntEnum):
+    """Sort order for GraphQl requests."""
+    ascending = 0
+    descending = 1
+
+    @classmethod
+    def parse_value(cls, value, default=None):
+        if value in (cls.ascending, "ascending", "asc"):
+            return cls.ascending
+        if value in (cls.descending, "descending", "desc"):
+            return cls.descending
+        return default
+
+
 def get_default_timeout():
     """Default value for requests timeout.
 
@@ -767,7 +782,11 @@ def _get_media_mime_type_from_ftyp(content):
     return None
 
 
-def get_media_mime_type_for_content(content: bytes) -> Optional[str]:
+def _get_media_mime_type_for_content_base(content: bytes) -> Optional[str]:
+    """Determine Mime-Type of a file.
+
+    Use header of the file to determine mime type (needs 12 bytes).
+    """
     content_len = len(content)
     # Pre-validation (largest definition check)
     # - hopefully there cannot be media defined in less than 12 bytes
@@ -790,10 +809,6 @@ def get_media_mime_type_for_content(content: bytes) -> Optional[str]:
     if content[0:4] == b"\211PNG":
         return "image/png"
 
-    # SVG
-    if b'xmlns="http://www.w3.org/2000/svg"' in content:
-        return "image/svg+xml"
-
     # JPEG, JFIF or Exif
     if (
         content[0:4] == b"\xff\xd8\xff\xdb"
@@ -820,6 +835,32 @@ def get_media_mime_type_for_content(content: bytes) -> Optional[str]:
     return None
 
 
+def _get_svg_mime_type(content: bytes) -> Optional[str]:
+    # SVG
+    if b'xmlns="http://www.w3.org/2000/svg"' in content:
+        return "image/svg+xml"
+    return None
+
+
+def get_media_mime_type_for_content(content: bytes) -> Optional[str]:
+    mime_type = _get_media_mime_type_for_content_base(content)
+    if mime_type is not None:
+        return mime_type
+    return _get_svg_mime_type(content)
+
+
+def get_media_mime_type_for_stream(stream) -> Optional[str]:
+    # Read only 12 bytes to determine mime type
+    content = stream.read(12)
+    if len(content) < 12:
+        return None
+    mime_type = _get_media_mime_type_for_content_base(content)
+    if mime_type is None:
+        content += stream.read()
+        mime_type = _get_svg_mime_type(content)
+    return mime_type
+
+
 def get_media_mime_type(filepath: str) -> Optional[str]:
     """Determine Mime-Type of a file.
 
@@ -834,6 +875,53 @@ def get_media_mime_type(filepath: str) -> Optional[str]:
         return None
 
     with open(filepath, "rb") as stream:
-        content = stream.read()
+        return get_media_mime_type_for_stream(stream)
 
-    return get_media_mime_type_for_content(content)
+
+def take_web_action_event(
+    server_url: str,
+    action_token: str
+) -> Dict[str, Any]:
+    """Take web action event using action token.
+
+    Action token is generated by AYON server and passed to AYON launcher.
+
+    Args:
+        server_url (str): AYON server url.
+        action_token (str): Action token.
+
+    Returns:
+        Dict[str, Any]: Web action event.
+
+    """
+    response = requests.get(
+        f"{server_url}/api/actions/take/{action_token}"
+    )
+    response.raise_for_status()
+    return response.json()
+
+
+def abort_web_action_event(
+    server_url: str,
+    action_token: str,
+    reason: str
+):
+    """Abort web action event using action token.
+
+    A web action event could not be processed for some reason.
+
+    Args:
+        server_url (str): AYON server url.
+        action_token (str): Action token.
+        reason (str): Reason why webaction event was aborted.
+
+    Returns:
+        requests.Response: Response from server.
+
+    """
+    response = requests.post(
+        f"{server_url}/api/actions/abort/{action_token}",
+        json={"message": reason},
+    )
+    response.raise_for_status()
+    return response
